==> nextcloud-app-bookmarks-1:12.0.0-2.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/mk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Детали",
    "Rename" : "Преименувај",
    "Copy link" : "Копирај линк",
    "Move" : "Премести",
    "Delete" : "Избриши",
    "Delete selection" : "Избриши ги селектираните",
    "Select all" : "Избери се",
    "Go back" : "Назад",
    "Share folder" : "Сподели папка",
    "New" : "Ново",
    "New folder" : "Нова папка",
    "RSS feed copied" : "RSS канал копиран",
    "Rename folder" : "Преименувај папка",
    "Delete folder" : "Избриши папка",
    "Submit" : "Испрати",
    "Cancel" : "Откажи",
    "Recent" : "Неодамнешни",
    "Shared with you" : "Споделено со вас",
    "Files" : "Датотеки",
    "Import" : "Увези",
    "Export" : "Извези",
    "Title" : "Наслов",
    "Link" : "Линк",
    "Tags" : "Ознаки",
    "Notes" : "Белешки",
    "Open file" : "Отвори датотека",
    "Owner" : "Сопственик",
    "Sharing" : "Споделување",
    "Select a user or group" : "Избери корисник или група",
    "Share link" : "Сподели линк",
    "Copy RSS feed" : "Копирај RSS канал",
    "Allow editing" : "Овозможи уредување",
    "Allow resharing" : "Дозволи повторно споделување",
    "Remove share" : "Отстрани споделување",
    "Projects" : "Проекти",
    "Link copied" : "Линкот е копиран",
    "Privacy" : "Приватност",
    "Failed to save settings" : "Неуспешно зачувување на параметрите",
    "Failed to load settings" : "Неуспешно вчитување на параметрите",
    "Folder" : "Папка",
    "Save" : "Зачувај"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-bookmarks-1:13.1.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/bookmarks/l10n/mk.js <==
OC.L10N.register(
    "bookmarks",
    {
    "Details" : "Детали",
    "Rename" : "Преименувај",
    "Copy link" : "Копирај линк",
    "Move" : "Премести",
    "Delete" : "Избриши",
    "Delete selection" : "Избриши ги селектираните",
    "Select all" : "Избери се",
    "Go back" : "Назад",
    "Share folder" : "Сподели папка",
    "New" : "Ново",
    "New folder" : "Нова папка",
    "Search" : "Барај",
    "RSS feed copied" : "RSS канал копиран",
    "Rename folder" : "Преименувај папка",
    "Delete folder" : "Избриши папка",
    "Submit" : "Испрати",
    "Cancel" : "Откажи",
    "Recent" : "Неодамнешни",
    "Shared with you" : "Споделено со вас",
    "Files" : "Датотеки",
    "Import" : "Увези",
    "Export" : "Извези",
    "Title" : "Наслов",
    "Link" : "Линк",
    "Tags" : "Ознаки",
    "Notes" : "Белешки",
    "Download file" : "Преземи датотека",
    "Owner" : "Сопственик",
    "Sharing" : "Споделување",
    "Select a user or group" : "Избери корисник или група",
    "Share link" : "Сподели линк",
    "Copy RSS feed" : "Копирај RSS канал",
    "Allow editing" : "Овозможи уредување",
    "Allow resharing" : "Дозволи повторно споделување",
    "Remove share" : "Отстрани споделување",
    "Link copied" : "Линкот е копиран",
    "Privacy" : "Приватност",
    "Failed to save settings" : "Неуспешно зачувување на параметрите",
    "Failed to load settings" : "Неуспешно вчитување на параметрите",
    "Folder" : "Папка",
    "Save" : "Зачувај"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
